@@ -6,16 +6,22 @@
 #' Downside deviation, similar to semi deviation, eliminates positive returns
 #' when calculating risk.  Instead of using the mean return or zero, it uses
 #' the Minimum Acceptable Return as proposed by Sharpe (which may be the mean
-#' historical return or zero).
+#' historical return or zero). It measures the variability of underperformance
+#' below a minimum targer rate. The downside variance is the square of the downside
+#' potential.
 #' 
 #' To calculate it, we take the subset of returns that are less than the target
 #' (or Minimum Acceptable Returns (MAR)) returns and take the differences of
 #' those to the target.  We sum the squares and divide by the total number of
 #' returns to get a below-target semi-variance.
 #' 
-#' \deqn{ DownsideDeviation(R , MAR)= \delta_{MAR} = \sqrt{
-#' \frac{\sum^{n}_{t=1}(R_{t} - MAR)^{2}}{n} } }
-#' 
+#'
+#' \deqn{DownsideDeviation(R , MAR) = \delta_{MAR} = \sqrt{\sum^{n}_{t=1}\frac{min[(R_{t} - MAR), 0]^2}{n}}}{DownsideDeviation(R, MAR) = sqrt(1/n * sum(t=1..n)((min(R(t)-MAR, 0))^2))}
+#'
+#' \deqn{ DownsideVariance(R, MAR) = \sum^{n}_{t=1}\frac{min[(R_{t} - MAR), 0]^2}{n}}{DownsideVariance(R, MAR) = 1/n * sum(t=1..n)((min(R(t)-MAR, 0))^2)}
+#'
+#' \deqn{DownsidePotential(R, MAR) = \sum^{n}_{t=1}\frac{min[(R_{t} - MAR), 0]} {n}}{DownsidePotential(R, MAR) =  1/n * sum(t=1..n)(min(R(t)-MAR, 0))}
+#'
 #' where \eqn{n} is either the number of observations of the entire series or
 #' the number of observations in the subset of the series falling below the
 #' MAR.
@@ -47,17 +53,22 @@
 #' future, we'll add a fitted option to this function, and would be happy to
 #' accept a contribution of this nature.
 #' 
-#' @aliases DownsideDeviation SemiDeviation SemiVariance
+#' @aliases DownsideDeviation SemiDeviation SemiVariance DownsidePotential
 #' @param R an xts, vector, matrix, data frame, timeSeries or zoo object of
 #' asset returns
 #' @param MAR Minimum Acceptable Return, in the same periodicity as your
 #' returns
 #' @param method one of "full" or "subset", indicating whether to use the
 #' length of the full series or the length of the subset of the series below
-#' the MAR as the denominator, defaults to "subset"
-#' @author Peter Carl, Brian G. Peterson
+#' the MAR as the denominator, defaults to "full"
+#' @param \dots any other passthru parameters
+#' @param potential if TRUE, calculate downside potential instead, default
+#' FALSE
+#' @author Peter Carl, Brian G. Peterson, Matthieu Lestel
 #' @references Sortino, F. and Price, L. Performance Measurement in a Downside
-#' Risk Framework. \emph{Journal of Investing}. Fall 1994, 59-65. \cr
+#' Risk Framework. \emph{Journal of Investing}. Fall 1994, 59-65. \cr 
+#' Carl Bacon, \emph{Practical portfolio performance measurement and attribution}, 
+#' second edition 2008
 #' 
 #' Plantinga, A., van der Meer, R. and Sortino, F. The Impact of Downside Risk
 #' on Risk-Adjusted Performance of Mutual Funds in the Euronext Markets. July
@@ -68,19 +79,29 @@
 #' \url{http://en.wikipedia.org/wiki/Semivariance}
 #' @keywords ts multivariate distribution models
 #' @examples
+#'
+#' #with data used in Bacon 2008
+#'
+#' data(portfolio_bacon)
+#' MAR = 0.5
+#' DownsideDeviation(portfolio_bacon[,1], MAR) #expected 0.493
+#' DownsidePotential(portfolio_bacon[,1], MAR) #expected 0.491
 #' 
+#' #with data of managers
+#'
 #' data(managers)
-#' sd.xts(managers[,1:6], na.rm=TRUE)
+#' apply(managers[,1:6], 2, sd, na.rm=TRUE)
 #' DownsideDeviation(managers[,1:6])  # MAR 0%
 #' DownsideDeviation(managers[,1:6], MAR = .04/12) #MAR 4%
 #' SemiDeviation(managers[,1,drop=FALSE])
 #' SemiDeviation(managers[,1:6])
 #' SemiVariance (managers[,1,drop=FALSE])
 #' SemiVariance (managers[,1:6]) #calculated using method="subset"
-#' 
+#'
+#' @export 
 DownsideDeviation <-
-function (R, MAR = 0, method=c("subset","full"), ..., potential=FALSE)
-{ # @author Peter Carl
+function (R, MAR = 0, method=c("full","subset"), ..., potential=FALSE)
+{ # @author Peter Carl, Matthieu Lestel
 
     # DESCRIPTION:
     # Downside deviation, similar to semi deviation, eliminates positive returns
@@ -93,8 +114,9 @@ function (R, MAR = 0, method=c("subset","full"), ..., potential=FALSE)
     # MAR = mean(x)
 
     method = method[1] 
+    R = checkData(R, method="matrix")
 
-    if (is.vector(R)) {
+    if (ncol(R)==1 || is.vector(R) || is.null(R)) {
         R = na.omit(R)
 
         r = subset(R, R < MAR)
@@ -112,9 +134,13 @@ function (R, MAR = 0, method=c("subset","full"), ..., potential=FALSE)
             full   = {len = length(R)},
             subset = {len = length(r)} #previously length(R)
         ) # end switch
-        p=2
-        if(potential) p=1 # calculates downside potential instead
-        result = sqrt(sum((r - MAR)^p)/len)
+
+        if(potential) { # calculates downside potential instead
+        	 result = sum((MAR - r)/len)
+	}
+	else {
+	     result = sqrt(sum((MAR - r)^2/len))
+	}
         return(result)
     }
     else {
@@ -123,39 +149,40 @@ function (R, MAR = 0, method=c("subset","full"), ..., potential=FALSE)
         result<-t(result)
         colnames(result) = colnames(R)
         if(potential)
-            rownames(result) = paste("Downside Potential (MAR = ", round(mean(MAR)*100,1),"%)", sep="")
+            rownames(result) = paste("Downside Potential (MAR = ", round(mean(MAR),1),"%)", sep="")
         else
-            rownames(result) = paste("Downside Deviation (MAR = ", round(mean(MAR)*100,1),"%)", sep="")
+            rownames(result) = paste("Downside Deviation (MAR = ", round(mean(MAR),1),"%)", sep="")
         return(result)
     }
 }
 
 DownsidePotential <-
-function (R)
-{ # @author Peter Carl
+function (R, MAR=0)
+{ # @author Peter Carl, Matthieu Lestel
 
     # DESCRIPTION:
-    # This function is just a wrapper of DownsideDeviation with
-    # MAR = mean(x) and potential = TRUE
-    # see below
+    # To calculate Downside Potential, we take the returns that are less
+    # than the target (or Minimum Acceptable Returns (MAR)) returns and take the
+    # differences of those to the target.  We sum and divide by the
+    # total number of returns.
 
     # FUNCTION:
     
     
-    if (is.vector(R)) {
-        R = na.omit(R)
-        return(DownsideDeviation(R, MAR=mean(R), method="full", potential=TRUE))
+    if (is.vector(R) || is.null(R) || ncol(R)==1) {
+        return(DownsideDeviation(R, MAR=MAR, method="full", potential=TRUE))
     }
     else {
-        R = checkData(R, method = "matrix")
-        MAR=mean(R) #dummy for R CMD check
-        result = apply(R, 2, DownsidePotential)
+        R = checkData(R)
+        result = apply(R, MARGIN = 2, DownsidePotential, MAR = MAR)
         result = matrix(result, nrow=1)
         colnames(result) = colnames(R)
-        rownames(result) = paste("Downside Potential (MAR = ", round(mean(MAR)*100,1),"%)", sep="")
+        rownames(result) = paste("Downside Potential (MAR = ", round(mean(MAR),1),"%)", sep="")
         return(result)
     }
 }
+
+
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
@@ -164,6 +191,6 @@ function (R)
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: DownsideDeviation.R 1889 2012-03-29 22:36:47Z braverock $
+# $Id: DownsideDeviation.R 2271 2012-09-02 01:56:23Z braverock $
 #
 ###############################################################################
