@@ -9,13 +9,15 @@
 #' @param FUN any function that can be evaluated using a single set of returns
 #' (e.g., rolling \code{\link{CAPM.beta}} won't work, but
 #' \code{\link{Return.annualized}} will)
-#' @param na.pad TRUE/FALSE If TRUE it adds any times that would not otherwise
-#' have been in the result with a value of NA. If FALSE those times are
-#' dropped.
+#' @param fill a three-component vector or list (recycled otherwise) providing 
+#' filling values at the left/within/to the right of the data range. See the 
+#' fill argument of \code{\link{na.fill}} for details.
 #' @param main set the chart title, same as in \code{\link{plot}}
 #' @param ylim set the y-axis limit, same as in \code{\link{plot}}
 #' @param \dots any other passthru parameters to \code{\link{plot}} or the
 #' function specified
+#' @details The parameter \code{na.pad} has been deprecated; use \code{fill = NA} instead of \code{na.pad = TRUE}, 
+#' or \code{fill = NULL} instead of \code{na.pad = FALSE}.
 #' @author Peter Carl
 #' @seealso \code{\link{charts.RollingPerformance}},
 #' \code{\link[zoo]{rollapply}}
@@ -24,10 +26,17 @@
 #' 
 #' data(edhec)
 #' chart.RollingPerformance(edhec[, 1:3], width = 24)
-#' chart.RollingPerformance(edhec[, 1:3], FUN = 'mean', width = 24, colorset = rich8equal, lwd = 2, legend.loc = "topleft", main = "Rolling 24-Month Mean Return")
-#' chart.RollingPerformance(edhec[, 1:3], FUN = 'SharpeRatio.annualized', width = 24, colorset = rich8equal, lwd = 2, legend.loc = "topleft", main = "Rolling 24-Month Sharpe Ratio")
+#' chart.RollingPerformance(edhec[, 1:3], 
+#' 		FUN = 'mean', width = 24, colorset = rich8equal, 
+#' 		lwd = 2, legend.loc = "topleft", 
+#' 		main = "Rolling 24-Month Mean Return")
+#' chart.RollingPerformance(edhec[, 1:3], 
+#' 		FUN = 'SharpeRatio.annualized', width = 24, 
+#' 		colorset = rich8equal, lwd = 2, legend.loc = "topleft", 
+#' 		main = "Rolling 24-Month Sharpe Ratio")
 #' 
-chart.RollingPerformance <- function (R, width = 12, FUN = "Return.annualized", ..., na.pad = TRUE, ylim=NULL, main=NULL)
+#' @export 
+chart.RollingPerformance <- function (R, width = 12, FUN = "Return.annualized", ...,  ylim = NULL, main = NULL, fill = NA)
 { # @author Peter Carl
 
     # DESCRIPTION:
@@ -63,7 +72,7 @@ chart.RollingPerformance <- function (R, width = 12, FUN = "Return.annualized",
 	
 	funargs$width=width
 	funargs$FUN=FUN
-	funargs$na.pad=na.pad
+	funargs$fill = fill
 	funargs$align='right'
 
 	# Calculate
@@ -113,6 +122,6 @@ chart.RollingPerformance <- function (R, width = 12, FUN = "Return.annualized",
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.RollingPerformance.R 1883 2012-03-25 00:59:31Z braverock $
+# $Id: chart.RollingPerformance.R 2319 2013-01-28 23:17:29Z peter_carl $
 #
 ###############################################################################
